<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>Ein einfaches und desktopunabhängiges Qt Datei-Archivierungsprogramm</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>Autoren</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>Programmierung:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver wurde von folgenden Programmen abgeleitet:
* Engrampa der Desktopumgebung MATE
* File Roller der Desktopumgebung Gnome
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>LXQt Archiver

Urheberrecht (C) 2020das LXQt Team

Dieses Programm ist freie Software; Weiterverteilung und/oder 
Modifizierung unter den Richtlinien der &apos;GNU General Public License&apos; 
gemäß der Free Software Foundation ist gestattet, ersichtlich in 
Lizenzversion 2 und in weiteren Neuauflagen der Lizenz.

Dieses Programm wird zur Verfügung gestellt, in der Hoffnung 
seinen Nutzern hilfreich zu sein, jedoch OHNE EINE GARANTIE 
und ohne einer implizierten Garantie auf MARKTGÄNGIGKEIT 
oder ZWECKGEBUNDENER FUNKTIONSFÄHIGKEIT. Weitere 
Einzelheiten sind in der &apos;GNU General Public License&apos; ersichtlich.

Eine Kopie der &apos;GNU General Public License&apos; sollten sie zusammen 
mit dieser Software enthalten haben. Falls nicht, kontaktieren Sie bitte 
die Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston, 
MA 02110, USA.</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>Archivtyp nicht unterstützt.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*%1 Dateien (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>Alle unterstützten Formate</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>Der Befehl konnte nicht ausgeführt werden.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>Befehl nicht gefunden.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>Der Befehl wurde fehlerhaft beendet.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>Passwort ist erforderlich.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>Datenträger fehlt.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>Fehlerhafter Zeichensatz.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>Nicht unterstütztes Dateiformat.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>Unbekannte Fehler sind aufgetreten.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>Aufteilen in Einheiten von</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>Dateiliste auch verschlüsseln</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="12"/>
        <source>Create Archive</source>
        <translation>Archiv erstellen</translation>
    </message>
    <message>
        <location filename="../createfiledialog.cpp" line="14"/>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>Entpacken</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>Alle Dateien e&amp;ntpacken</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>Ausgewählte Dateien en&amp;tpacken</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>Aktionen</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>Ordner neu erstellen</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="75"/>
        <source>Overwrite existing files</source>
        <translation>Existierende Dateien überschreiben</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="82"/>
        <source>Do not extract older files</source>
        <translation>Ältere Dateien nicht entpacken</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="11"/>
        <source>Extract</source>
        <translation>Entpacken</translation>
    </message>
    <message>
        <location filename="../extractfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>File Archiver</source>
        <translation>Dateiarchivierung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>Dateien filtern…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>&amp;Icon Size</source>
        <translation>&amp;Symbolgröße</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="152"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Main Toolbar</source>
        <translation>Hauptwerkzeugleiste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Ctrl+N</source>
        <translation>Strg+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>&amp;Open</source>
        <translation>&amp;Öffnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>Ctrl+O</source>
        <translation>Strg+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <source>Save &amp;As</source>
        <translation>Speichern &amp;unter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Ctrl+Shift+S</source>
        <translation>Strg+Shift+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>&amp;Extract</source>
        <translation>&amp;Entpacken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <source>&amp;Test</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>Ctrl+T</source>
        <translation>Strg+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="251"/>
        <source>&amp;Properties</source>
        <translation>&amp;Eigenschaften</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>Ctrl+Q</source>
        <translation>Strg+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Ausschneiden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+X</source>
        <translation>Strg+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>Ctrl+C</source>
        <translation>Strg+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>&amp;Paste</source>
        <translation>&amp;Einfügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>Ctrl+V</source>
        <translation>Strg+V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>&amp;Rename</source>
        <translation>&amp;Umbenennen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Del</source>
        <translation>Entf</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>&amp;Select All</source>
        <translation>Alle&amp;s auswählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Ctrl+A</source>
        <translation>Strg+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>&amp;Find</source>
        <translation>&amp;Finden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="345"/>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Ctrl+F</source>
        <translation>Strg+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="350"/>
        <source>&amp;Add Files</source>
        <translation>&amp;Dateien hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Add F&amp;older</source>
        <translation>&amp;Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Pass&amp;word</source>
        <translation>Kenn&amp;wort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>&amp;Statusbar</source>
        <translation>&amp;Statusleiste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>&amp;Directory Tree</source>
        <translation>&amp;Verzeichnisbaum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>S&amp;how as Folder</source>
        <translation>A&amp;ls Ordner anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Ctrl+Shift+D</source>
        <translation>Strg+Shift+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Show &amp;All Files</source>
        <translation>&amp;Alle Dateien anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Ctrl+Shift+A</source>
        <translation>Strg+Shift+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>St&amp;op</source>
        <translation>An&amp;halten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="434"/>
        <source>Esc</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="443"/>
        <source>&amp;Reload</source>
        <translation>Neu &amp;laden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Filename &amp;Encoding</source>
        <translation>Dat&amp;einamenkodierung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>&amp;View Selected Items</source>
        <translation>&amp;Ausgewählte Elemente anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="461"/>
        <source>&amp;Filter</source>
        <translation>&amp;Filter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>&amp;Expand</source>
        <translation>&amp;Ausklappen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Ctrl+Shift+E</source>
        <translation>Strg+Shift+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="486"/>
        <source>Ctrl+Shift+C</source>
        <translation>Strg+Shift+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="483"/>
        <source>&amp;Collapse</source>
        <translation>&amp;Einklappen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>16 px</source>
        <translation>16 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="502"/>
        <source>24 px</source>
        <translation>24 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>32 px</source>
        <translation>32 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="518"/>
        <source>48 px</source>
        <translation>48 px</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <location filename="../mainwindow.cpp" line="403"/>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>Add only if &amp;newer</source>
        <translation>Nur hinzufügen, wenn &amp;neuer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Sind Sie sicher, dass Sie ausgewählte Dateien löschen möchten?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <source>Version: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="878"/>
        <source>%p %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="982"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="982"/>
        <source>No errors have been found.</source>
        <translation>Es wurden keine Fehler gefunden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="960"/>
        <location filename="../mainwindow.cpp" line="1020"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Add Files</source>
        <translation>Dateien hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Add Folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1050"/>
        <source>N/A</source>
        <translation>N/V</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <source>Uncompressed Size:</source>
        <translation>Unkomprimierte Größe:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1056"/>
        <source>Compression Ratio:</source>
        <translation>Komprimierungsverhältnis:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1075"/>
        <source>Link to</source>
        <translation>Link zu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1114"/>
        <source>File name</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1115"/>
        <source>File Type</source>
        <translation>Dateityp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1116"/>
        <source>File Size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1117"/>
        <source>Modified</source>
        <translation>Geändert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1118"/>
        <source>Encrypted</source>
        <translation>Verschlüsselt</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1145"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>%n Datei</numerusform>
            <numerusform>%n Dateien</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>Kennwort</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>Dateiliste verschlüsseln</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>Passwort anzeigen</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;Hinweis:&lt;/b&gt; Das Passwort wird verwendet, um Dateien zu verschlüsseln, die Sie dem aktuellen Archiv hinzufügen, und um Dateien zu entschlüsseln, die Sie aus dem aktuellen Archiv entpacken. Wenn das Archiv geschlossen wird, wird das Passwort gelöscht.&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="300"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>Tar komprimiert mit 7z (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>Tar komprimiert mit bzip2 (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>Tar komprimiert mit bzip (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>Rar archiviertes Comicbuch (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>Zip archiviertes Comicbuch (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>Tar komprimiert mit gzip (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>Selbstentpackende Zip (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>Tar komprimiert mit lrzip (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>Tar komprimiert mit lzip (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>Tar komprimiert mit lzma (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>Tar komprimiert mit lzop (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Tar unkomprimiert (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>Tar komprimiert mit compress (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>Tar komprimiert mit xz (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>Tar komprimiert mit zstd (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>Füge Datei hinzu: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="282"/>
        <source>Extracting file: </source>
        <translation>Entpacke Datei: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>Entferne Datei: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>Lösche Dateien aus dem Archiv</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>Komprimiere Archiv erneut</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>Dekomprimiere Archiv</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>Datei nicht gefunden.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>Archivtyp nicht unterstützt.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>Archiv nicht gefunden</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>Sie haben nicht die richtigen Berechtigungen.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>Dieser Archivtyp kann nicht geändert werden</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>Sie können ein Archiv nicht zu sich selbst hinzufügen.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>Konnte Datenträger nicht finden: %s</translation>
    </message>
</context>
</TS>
